==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/fstab/fstab.m <==
extern const char **_dictionary_fstab;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_fstab;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_fstab("fstab",_dictionary_fstab,159,7);\
	void dummy_dict_fstab(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_fstab[id]
	#define MSG_B(id,m,n)	_dictionary_fstab[id]
	#define MSG_R(id)	_dictionary_fstab[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_fstab,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_fstab,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_fstab,id)
#endif
#define M_LOCALD	0
#define M_NFSVOL	1
#define M_SAMBA	2
#define M_SWAP	3
#define M_FIXPERM	4
#define T_FSCONF	5
#define I_FSCONF	6
#define N_NOSAMBA	7
#define P_FIXPERM	8
#define N_ALLISOK	9
#define E_FSTABARG	10
#define F_SERVER	11
#define F_VOLUME	12
#define F_SHARE	13
#define F_PARTITION	14
#define F_TYPE	15
#define F_EXT2	16
#define F_MINIX	17
#define F_UMSDOS	18
#define F_OS2	19
#define F_UNIXV	20
#define F_XIAFS	21
#define F_MPOINT	22
#define T_GENOPTIONS	23
#define F_OPTIONS	24
#define F_READONLY	25
#define F_USERMNT	26
#define F_BOOTTIME	27
#define F_NOEXEC	28
#define F_NOSPC	29
#define F_NOSUID	30
#define T_MSOPT	31
#define F_DEFUID	32
#define F_DEFGID	33
#define F_DEFPERM	34
#define F_TRAMODE	35
#define F_NOTRA	36
#define F_EXTTRA	37
#define F_ALWTRANS	38
#define T_NFSOPT	39
#define F_SOFTMNT	40
#define F_BGMOUNT	41
#define F_READSIZE	42
#define F_OTHEROPT	43
#define F_COMMENT	44
#define T_VOLSPEC	45
#define I_VOLSPEC	46
#define T_LOCALVOL	47
#define T_NFSVOL	48
#define T_SMBVOL	49
#define T_SWAPSPACE	50
#define T_NOVELL	51
#define I_MOUNTS	52
#define I_ADDDEF	53
#define N_ROOTDEF	54
#define E_CANTVLD	55
#define E_NOMNTPT	56
#define Q_EXISTMNT	57
#define T_CANTMOUNT	58
#define E_ISNOTDIR	59
#define N_PROCADD	60
#define T_NOSWAP	61
#define Q_NOSWAP	62
#define T_AREYOUSURE	63
#define Q_BUGYOU	64
#define N_SOMEMODS	65
#define E_IVLDFDISK	66
#define L_CREATING	67
#define E_CONFFILE	68
#define E_IVLDOPT	69
#define E_IVLDDEV	70
#define E_IVLDTYPE	71
#define E_NOUSER	72
#define E_NOGROUP	73
#define L_CHGOWN	74
#define E_CANTCHG	75
#define L_CHGPERM	76
#define E_IVLDLINE	77
#define L_DIRECTORY	78
#define L_FILE	79
#define I_FIXMOUNT	80
#define Q_FIXMOUNT	81
#define I_REMOUNT	82
#define Q_REMOUNT	83
#define F_DUMPFREQ	84
#define F_CHKPRI	85
#define E_WRONGDEV	86
#define Q_DELENTRY	87
#define F_ISOFS	88
#define H_FSTAB	89
#define F_PATH	90
#define F_OWNER	91
#define F_GROUP	92
#define T_ONESPEC	93
#define H_PERMS	94
#define T_FILE	95
#define T_DIR	96
#define T_PERMS	97
#define I_PERMS	98
#define T_CHR	99
#define T_BLK	100
#define F_MAYEXEC	101
#define F_MAYWRITE	102
#define F_MAYREAD	103
#define T_USER	104
#define T_GROUP	105
#define T_OTHER	106
#define F_USRQUOTA	107
#define F_GRPQUOTA	108
#define T_QUOTADEF	109
#define I_QUOTADEF	110
#define M_QUOTA	111
#define F_SOFTK	112
#define F_HARDK	113
#define F_GRACEK	114
#define F_SOFTF	115
#define F_HARDF	116
#define F_GRACEF	117
#define T_USERDEF	118
#define T_GROUPDEF	119
#define I_QUOTACHECK	120
#define T_QUOTACHECK	121
#define F_VFAT	122
#define P_BASE	123
#define P_OPTIONS	124
#define P_MSDOS	125
#define P_MISC	126
#define T_SPCBITS	127
#define F_SETUID	128
#define F_SETGID	129
#define F_ONLYOWNER	130
#define F_WRITESIZE	131
#define E_NODEVQUOTA	132
#define H_FSTABNET	133
#define B_MOUNT	134
#define B_UMOUNT	135
#define E_ISMOUNTED	136
#define E_ISNOTMOUNTED	137
#define I_MOUNTED	138
#define I_CTRLMOUNTS	139
#define Q_UMOUNT	140
#define I_UMOUNT	141
#define Q_MOUNT	142
#define I_MOUNT	143
#define M_MANUAL	144
#define T_FSCONTROL	145
#define I_FSCONTROL	146
#define M_CTRLLOCAL	147
#define M_CTRLNFS	148
#define T_MANUALNFS	149
#define I_MANUALNFS	150
#define E_NOMPT	151
#define N_UMOUNTOK	152
#define N_MOUNTOK	153
#define F_NOLOCKMNT	154
#define P_MNGFS	155
#define I_NOLIMIT	156
#define I_DEFAULT	157
#define F_OWNERMNT	158

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/fstab/fstab.m <==
extern const char **_dictionary_fstab;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_fstab;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_fstab("fstab",_dictionary_fstab,169,7);\
	void dummy_dict_fstab(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_fstab[id]
	#define MSG_B(id,m,n)	_dictionary_fstab[id]
	#define MSG_R(id)	_dictionary_fstab[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_fstab,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_fstab,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_fstab,id)
#endif
#define M_LOCALD	0
#define M_NFSVOL	1
#define M_SAMBA	2
#define M_SWAP	3
#define M_FIXPERM	4
#define T_FSCONF	5
#define I_FSCONF	6
#define N_NOSAMBA	7
#define P_FIXPERM	8
#define N_ALLISOK	9
#define E_FSTABARG	10
#define F_SERVER	11
#define F_VOLUME	12
#define F_SHARE	13
#define F_PARTITION	14
#define F_TYPE	15
#define F_EXT2	16
#define F_MINIX	17
#define F_UMSDOS	18
#define F_OS2	19
#define F_UNIXV	20
#define F_XIAFS	21
#define F_MPOINT	22
#define T_GENOPTIONS	23
#define F_OPTIONS	24
#define F_READONLY	25
#define F_USERMNT	26
#define F_BOOTTIME	27
#define F_NOEXEC	28
#define F_NOSPC	29
#define F_NOSUID	30
#define T_MSOPT	31
#define F_DEFUID	32
#define F_DEFGID	33
#define F_DEFPERM	34
#define F_TRAMODE	35
#define F_NOTRA	36
#define F_EXTTRA	37
#define F_ALWTRANS	38
#define T_NFSOPT	39
#define F_SOFTMNT	40
#define F_BGMOUNT	41
#define F_READSIZE	42
#define F_OTHEROPT	43
#define F_COMMENT	44
#define T_VOLSPEC	45
#define I_VOLSPEC	46
#define T_LOCALVOL	47
#define T_NFSVOL	48
#define T_SMBVOL	49
#define T_SWAPSPACE	50
#define T_NOVELL	51
#define I_MOUNTS	52
#define I_ADDDEF	53
#define N_ROOTDEF	54
#define E_CANTVLD	55
#define E_NOMNTPT	56
#define Q_EXISTMNT	57
#define T_CANTMOUNT	58
#define E_ISNOTDIR	59
#define N_PROCADD	60
#define T_NOSWAP	61
#define Q_NOSWAP	62
#define T_AREYOUSURE	63
#define Q_BUGYOU	64
#define N_SOMEMODS	65
#define E_IVLDFDISK	66
#define L_CREATING	67
#define E_CONFFILE	68
#define E_IVLDOPT	69
#define E_IVLDDEV	70
#define E_IVLDTYPE	71
#define E_NOUSER	72
#define E_NOGROUP	73
#define L_CHGOWN	74
#define E_CANTCHG	75
#define L_CHGPERM	76
#define E_IVLDLINE	77
#define L_DIRECTORY	78
#define L_FILE	79
#define I_FIXMOUNT	80
#define Q_FIXMOUNT	81
#define I_REMOUNT	82
#define Q_REMOUNT	83
#define F_DUMPFREQ	84
#define F_CHKPRI	85
#define E_WRONGDEV	86
#define Q_DELENTRY	87
#define F_ISOFS	88
#define H_FSTAB	89
#define F_PATH	90
#define F_OWNER	91
#define F_GROUP	92
#define T_ONESPEC	93
#define H_PERMS	94
#define T_FILE	95
#define T_DIR	96
#define T_PERMS	97
#define I_PERMS	98
#define T_CHR	99
#define T_BLK	100
#define F_MAYEXEC	101
#define F_MAYWRITE	102
#define F_MAYREAD	103
#define T_USER	104
#define T_GROUP	105
#define T_OTHER	106
#define F_USRQUOTA	107
#define F_GRPQUOTA	108
#define T_QUOTADEF	109
#define I_QUOTADEF	110
#define M_QUOTA	111
#define F_SOFTK	112
#define F_HARDK	113
#define F_GRACEK	114
#define F_SOFTF	115
#define F_HARDF	116
#define F_GRACEF	117
#define T_USERDEF	118
#define T_GROUPDEF	119
#define I_QUOTACHECK	120
#define T_QUOTACHECK	121
#define F_VFAT	122
#define P_BASE	123
#define P_OPTIONS	124
#define P_MSDOS	125
#define P_MISC	126
#define T_SPCBITS	127
#define F_SETUID	128
#define F_SETGID	129
#define F_ONLYOWNER	130
#define F_WRITESIZE	131
#define E_NODEVQUOTA	132
#define H_FSTABNET	133
#define B_MOUNT	134
#define B_UMOUNT	135
#define E_ISMOUNTED	136
#define E_ISNOTMOUNTED	137
#define I_MOUNTED	138
#define I_CTRLMOUNTS	139
#define Q_UMOUNT	140
#define I_UMOUNT	141
#define Q_MOUNT	142
#define I_MOUNT	143
#define M_MANUAL	144
#define T_FSCONTROL	145
#define I_FSCONTROL	146
#define M_CTRLLOCAL	147
#define M_CTRLNFS	148
#define T_MANUALNFS	149
#define I_MANUALNFS	150
#define E_NOMPT	151
#define N_UMOUNTOK	152
#define N_MOUNTOK	153
#define F_NOLOCKMNT	154
#define P_MNGFS	155
#define I_NOLIMIT	156
#define I_DEFAULT	157
#define F_OWNERMNT	158
#define I_WHYQUOTAUSER	159
#define I_WHYQUOTAGROUP	160
#define I_NOTMOUNTED	161
#define I_NEWSOURCE	162
#define I_NEWMOUNTOPTS	163
#define E_TRANSLATELABEL	164
#define E_IVLDQUOTAOPT	165
#define E_MISSDEVICE	166
#define E_IVLDQUOTAVAL	167
#define E_NOQUOTADEV	168
